.. _api-shortcuts:

Shortcuts
=========

.. automodule:: guardian.shortcuts


.. _api-shortcuts-assign:

assign_perm
-----------

.. autofunction:: guardian.shortcuts.assign_perm

.. _api-shortcuts-remove_perm:

remove_perm
-----------

.. autofunction:: guardian.shortcuts.remove_perm

.. _api-shortcuts-get_perms:

get_perms
---------

.. autofunction:: guardian.shortcuts.get_perms


.. _api-shortcuts-get_perms_for_model:

get_perms_for_model
-------------------

.. autofunction:: guardian.shortcuts.get_perms_for_model


.. _api-shortcuts-get_users_with_perms:

get_users_with_perms
--------------------

.. autofunction:: guardian.shortcuts.get_users_with_perms


.. _api-shortcuts-get_groups_with_perms:

get_groups_with_perms
---------------------

.. autofunction:: guardian.shortcuts.get_groups_with_perms


.. _api-shortcuts-get_objects_for_user:

.. shortcut:: get_objects_for_user

get_objects_for_user
--------------------

.. autofunction:: guardian.shortcuts.get_objects_for_user

get_objects_for_group
---------------------

.. autofunction:: guardian.shortcuts.get_objects_for_group
